@@ -15,7 +15,7 @@
 ## along with this program; see the file COPYING. If not, write to the
 ## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id: customconfig.py 66391 2008-06-09 17:38:35Z glenfant $
+# $Id: customconfig.py 69081 2008-07-28 13:39:24Z b_mathieu $
 """
 Custom config data
 """
@@ -23,6 +23,7 @@ __author__  = 'Gilles Lenfant <gilles.lenfant@ingeniweb.com>'
 __docformat__ = 'restructuredtext'
 
 import os
-ZOPETESTCASE = os.environ.has_key('ZOPE_TESTCASE')
+ZOPETESTCASE = (('ZOPE_TESTCASE' in os.environ)
+                or ('ZOPETESTCASE' in os.environ))
 del os
 INSTALL_EXAMPLE_TYPES_ENVIRONMENT_VARIABLE = 'FSS_INSTALL_EXAMPLE_TYPES'
