@@ -16,7 +16,7 @@
 ## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 """
 Testing FSS features
-$Id: testFSS.py 66025 2008-06-02 13:53:50Z glenfant $
+$Id: testFSS.py 69084 2008-07-28 14:28:25Z b_mathieu $
 """
 
 from common import *
@@ -625,7 +625,7 @@ class TestFSS(FSSTestCase.FSSTestCase):
         file_value = file_field.get(file_content)
 
         # Test absolute_url
-        url = '%(instance_url)s/fss_get/%(name)s' % {
+        url = '%(instance_url)s/%(name)s' % {
             'instance_url': file_content.absolute_url(),
             'name': 'file',
             }
